## Descripción del proyecto

El proyecto **colorin** consiste en una clase que permite el coloreado y el formateo de la salida estándar para la terminal en lenguaje **python**.

A su vez, la clase es polimórfica y se puede instanciar indicando los títulos de la cabecera para generar tablas de datos y gráficas de columnas verticales.

Uso de la clase y ejemplos:    
[https://github.com/gmolino/colorin](https://github.com/gmolino/colorin)

## Versiones

##### 0.0.2

* Se agrega el método para mostrar gráficas verticales.

##### 0.0.1

* Primer commit con los métodos descritos en el proyecto.
